@@ -25,10 +25,12 @@ class AnnotationValueJSON(object):
       return self._annotationTime
 
     def toDict(self):
+        from .epmnodeids import EpmNodeIds
         return {'value': { 
                             'annotationTime' : self._annotationTime.isoformat(), 
                             'message' : self._message,
                             'userName' : self._userName 
                          }, 
                 'quality': 0, 
-                'timestamp' : self._annotationTime.isoformat() }
+                'timestamp' : self._annotationTime.isoformat(),
+                'dataTypeId': EpmNodeIds.AnnotationType.value }
