@@ -36,9 +36,10 @@ class DataValueJSON(object):
       return self._timestamp
 
     def toDict(self):
+        value = self._value.isoformat() if type(self._value) == datetime.datetime else self._value
         if self._dataTypeId is None:
-            return {'value': self._value, 'quality': self._statusCode,
+            return {'value': value, 'quality': self._statusCode,
                    'timestamp' : self._timestamp.isoformat()}
         else:
-            return {'value': self._value, 'quality': self._statusCode,
+            return {'value': value, 'quality': self._statusCode,
                     'timestamp': self._timestamp.isoformat(), 'dataTypeId': self._dataTypeId}
