@@ -13,8 +13,8 @@ from .epmvariable import EpmVariable
 class EpmProperty(EpmVariable):
     """description of class"""
 
-    def __init__(self, epmConnection, name, path, identity):
-        super().__init__(epmConnection, name, path, identity)
+    def __init__(self, epmConnection, name, path, itemPath):
+        super().__init__(epmConnection, name, path, itemPath)
 
 
 
