@@ -6,6 +6,10 @@ Distributed under the MIT License.
 """
 
 import json
+
+def fromDict(itemPathDict):
+    return ItemPathJSON(itemPathDict['language'], itemPathDict['context'], itemPathDict['path'])
+
 class ItemPathJSON(object):
     """description of class"""
     def __init__(self, language, context, path):
