@@ -14,6 +14,6 @@ class WriteModelJSON(object):
 
     childMap = []
     for item in self._items:
-        childMap.append(item.toDict());
+        childMap.append(item.toDict())
 
     return {'items': childMap }
